@@ -1,29 +1,28 @@
-from __future__ import print_function
-import sys
-import traceback
 import keyword
+import sys
 import time
-from functools import partial
 from code import InteractiveConsole
-from objc import YES, NO, selector, IBAction, IBOutlet, super
-from Cocoa import NSBundle, NSObject, NSTextView, NSForegroundColorAttributeName
-from Cocoa import NSFont, NSColor, NSFontAttributeName, NSApplication
-from Cocoa import NSUIntegerMax, NSDate, NSDefaultRunLoopMode, NSKeyDown
-from Cocoa import NSAttributedString
+from functools import partial
+
+from Cocoa import (
+    NSApplication,
+    NSAttributedString,
+    NSBundle,
+    NSColor,
+    NSControlKeyMask,
+    NSDate,
+    NSDefaultRunLoopMode,
+    NSFont,
+    NSFontAttributeName,
+    NSForegroundColorAttributeName,
+    NSKeyDown,
+    NSObject,
+    NSTextView,
+    NSUIntegerMax,
+)
+from objc import NO, YES, IBOutlet, super
 from PyObjCTools import AppHelper
-
-if sys.version_info[0] == 2:
-    exec(
-        """
-def exec_code(code, globals):
-    exec code in locals
-    """
-    )
-else:
-    unicode = str
-    import builtins
-
-    exec_code = getattr(builtins, "exec")
+import objc
 
 try:
     sys.ps1
@@ -35,14 +34,14 @@ except AttributeError:
     sys.ps2 = "... "
 
 
-class PseudoUTF8Output(object):
+class PseudoUTF8Output:
     softspace = 0
 
     def __init__(self, writemethod):
         self._write = writemethod
 
     def write(self, s):
-        if not isinstance(s, unicode):
+        if not isinstance(s, str):
             s = s.decode("utf-8", "replace")
         self._write(s)
 
@@ -57,7 +56,7 @@ class PseudoUTF8Output(object):
         return True
 
 
-class PseudoUTF8Input(object):
+class PseudoUTF8Input:
     softspace = 0
 
     def __init__(self, readlinemethod):
@@ -135,7 +134,7 @@ class AsyncInteractiveConsole(InteractiveConsole):
                 # next input function
                 yield _buff.append
                 more = self.push(_buff.pop())
-        except:
+        except:  # noqa: E722, B001
             self.lock = False
             raise
         self.lock = False
@@ -146,10 +145,10 @@ class AsyncInteractiveConsole(InteractiveConsole):
 
     def runcode(self, code):
         try:
-            exec_code(code, self.locals)
+            exec(code, self.locals)
         except SystemExit:
             raise
-        except:
+        except:  # noqa: E722, B001
             self.showtraceback()
         else:
             if sys.stdout.softspace:
@@ -165,7 +164,7 @@ class AsyncInteractiveConsole(InteractiveConsole):
             objname = ".".join(parts[:-1])
             try:
                 obj = eval(objname, self.locals)
-            except:
+            except:  # noqa: E722, B001
                 return None, 0
             wordlower = parts[-1].lower()
             if wordlower == "":
@@ -179,7 +178,9 @@ class AsyncInteractiveConsole(InteractiveConsole):
                 ]
             else:
                 # they started typing the method name
-                check = list(filter(lambda s: s.lower().startswith(wordlower), dir(obj)))
+                check = list(
+                    filter(lambda s: s.lower().startswith(wordlower), dir(obj))
+                )
         else:
             # no dots, must be in the normal namespaces.. no eval necessary
             check = set(dir(__builtins__))
@@ -223,7 +224,7 @@ class PyInterpreter(NSObject):
     #
 
     def awakeFromNib(self):
-        self = super(PyInterpreter, self).init()
+        self = super().init()
         self._font = NSFont.userFixedPitchFontOfSize_(10)
         self._stderrColor = NSColor.redColor()
         self._stdoutColor = NSColor.blueColor()
@@ -391,18 +392,29 @@ class PyInterpreter(NSObject):
                 continue
 
             if (event.type() == NSKeyDown) and (event.window() == window):
-                chr = event.charactersIgnoringModifiers()
-                if chr == "c" and (event.modifierFlags() & NSControlKeyMask):
+                char = event.charactersIgnoringModifiers()
+                if char == "c" and (event.modifierFlags() & NSControlKeyMask):
                     raise KeyboardInterrupt
 
             app.sendEvent_(event)
 
-    codeString_ = lambda self, s: self._formatString_forOutput_(s, "code")
-    stderrString_ = lambda self, s: self._formatString_forOutput_(s, "stderr")
-    stdoutString_ = lambda self, s: self._formatString_forOutput_(s, "stdout")
-    writeCode_ = lambda self, s: self._writeString_forOutput_(s, "code")
-    writeStderr_ = lambda self, s: self._writeString_forOutput_(s, "stderr")
-    writeStdout_ = lambda self, s: self._writeString_forOutput_(s, "stdout")
+    def codeString_(self, s):
+        return self._formatString_forOutput_(s, "code")
+
+    def stderrString_(self, s):
+        return self._formatString_forOutput_(s, "stderr")
+
+    def stdoutString_(self, s):
+        return self._formatString_forOutput_(s, "stdout")
+
+    def writeCode_(self, s):
+        return self._writeString_forOutput_(s, "code")
+
+    def writeStderr_(self, s):
+        return self._writeString_forOutput_(s, "stderr")
+
+    def writeStdout_(self, s):
+        return self._writeString_forOutput_(s, "stdout")
 
     #
     #  Accessors
@@ -432,7 +444,7 @@ class PyInterpreter(NSObject):
     def codeColor(self):
         return self._codeColor
 
-    def setStdoutColor_(self, color):
+    def setCodeColor_(self, color):
         self._codeColor = color
 
     def isInteracting(self):
@@ -475,9 +487,9 @@ class PyInterpreter(NSObject):
     #
 
     def textView_completions_forPartialWordRange_indexOfSelectedItem_(
-        self, aTextView, completions, range, index
+        self, aTextView, completions, word_range, index
     ):
-        (begin, length) = range
+        (begin, length) = word_range
         txt = self.textView.textStorage().mutableString()
         end = begin + length
         while (begin > 0) and (txt[begin].isalnum() or txt[begin] in "._"):
@@ -575,7 +587,5 @@ class PyInterpreter(NSObject):
 
 
 if __name__ == "__main__":
-    import objc
-
     objc.setVerbose(1)
     AppHelper.runEventLoop()
